clear;clc;close all

%--------------------------------------------------------------------------
%% Set up plot window location and size
%--------------------------------------------------------------------------
width=600;
height=400;
left=1;
bottom=1;

%--------------------------------------------------------------------------
%% Set up variables we will use for the interpolation
%--------------------------------------------------------------------------
% 2D interpolation
rand('state',0);
n=2000;
x = 2*(rand(n,1)-0.5);
y = 2*(rand(n,1)-0.5);
v = x.^5+y.^3;

%--------------------------------------------------------------------------
%% Plot points that make up our irregular x,y,z dataset
%--------------------------------------------------------------------------
% Plot points
figure('Position',[left, bottom, width, height])

plot3(x,y,v,'or');
set(gca,'LineWidth',1)
set(gca,'TickDir','out')
set(gca,'FontSize',16)     

fn=['3dplot'];
% Print to png file
fnpng=[fn,'.png']; print('-dpng',fnpng);
% Print to ps file
fnps=[fn,'.eps'];print('-depsc2',fnps);

%--------------------------------------------------------------------------
left=left+width;
if left>2*width
    left=1;
    bottom=bottom+height;
end

%--------------------------------------------------------------------------
%% Perform the interpolation
%--------------------------------------------------------------------------
% Interpolate to a regular grid
% First set up grid:
d = -1:0.01:1;
[Xi,Yi] = meshgrid(d,d);

% Use first linear then cubic interpolation
% Set any values less than a threshold of -1 to zero
thresh=-1.;

% first use linear then use cubic interpolation
for i=1:2
    if i==1
        method='linear';
    elseif i==2
        method='cubic';
    end
    string=['Vi_' method '=griddata(x,y,v,Xi,Yi,method);'];
    eval(string);
    
    % Set values less than the threshold to NaN;
    string=['iwant=find(Vi_' method '<thresh);'];
    eval(string);
    
    string=['Vi_' method '(iwant)=NaN;'];
    eval(string);    
    
    figure('Position',[left, bottom, width, height])
    string=['contourf(Xi,Yi,Vi_' method ',50)';]
    eval(string);
    set(gca,'LineWidth',1)
    set(gca,'TickDir','out')
    set(gca,'FontSize',16)                    
    colorbar
    title([method ' interpolation of  z=x^5+y^3'],'FontSize',22)
    grid on
    
    fn=['contour-' method];
    % Print to png file
    fnpng=[fn,'.png']; print('-dpng',fnpng);
    % Print to ps file
    fnps=[fn,'.eps'];print('-depsc2',fnps);
    
    c = caxis;
    cmin= c(1);
    cmax= c(2);
    cmap = colormap;
    cm_length=max(size(cmap));
    caxis manual

    hold on
    cdata=v;
    colormap_index = fix((cdata-cmin)/(cmax-cmin)*cm_length)+1;
    colormap_index = min(colormap_index,cm_length);
    colormap_index = max(colormap_index,1);
    iwant=find(v>thresh);
    for j=1:length(iwant)
        plot(x(iwant(j)),y(iwant(j)),'rs','LineWidth',0.001,'MarkerEdgeColor','k','MarkerFaceColor',cmap(colormap_index(iwant(j)),:),'MarkerSize',6)
    end
    hold off
    
    fn=['contour-' method '-with overlay'];
    % Print to png file
    fnpng=[fn,'.png']; print('-dpng',fnpng);
    % Print to ps file
    fnps=[fn,'.eps'];print('-depsc2',fnps);
    
    %--------------------------------------------------------------------------
    left=left+width;
    if left>2*width
        left=1;
        bottom=bottom+height;
    end
    %--------------------------------------------------------------------------

end

%--------------------------------------------------------------------------
% Plot difference
figure('Position',[left, bottom, width, height])
dif=Vi_cubic-Vi_linear;
contourf(Xi,Yi,dif,50);
set(gca,'LineWidth',1)
set(gca,'TickDir','out')
set(gca,'FontSize',16)                
colorbar
title('Difference','FontSize',22)
grid on

fn=['difference'];
% Print to png file
fnpng=[fn,'.png']; print('-dpng',fnpng);
% Print to ps file
fnps=[fn,'.eps'];print('-depsc2',fnps);
